package com.yifu.cloud.plus.v1.yifu.archives.utils;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmployeeInfo;
import com.yifu.cloud.plus.v1.yifu.archives.entity.TEmployeeProject;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeInfoService;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeLogService;
import com.yifu.cloud.plus.v1.yifu.archives.service.TEmployeeProjectService;
import com.yifu.cloud.plus.v1.yifu.common.core.constant.CommonConstants;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * 主要执行人员档案的员工类型同步更新
 * @author huyc
 * @Date 2022-07-08
 * @Description 多线程的执行demo
 */
@Slf4j
@Component
public class DoJointTask {

    @Autowired
    private TEmployeeInfoService tEmployeeInfoService;

	@Autowired
	private TEmployeeProjectService tEmployeeProjectService;

	@Autowired
	private TEmployeeLogService tEmployeeLogService;

    /**
     * @Description: 合同-批量更换负责人
     * @Author: huyc
     * @Date: 2022-7-8
     * @return: void
     **/
    @Async
    public void doUpdateEmployeeInfo(List<TEmployeeInfo> tEmployeeInfoList) {
        log.info("档案-批量更新人员档案-线程开始");
        try {
			for(TEmployeeInfo tEmployeeInfo:tEmployeeInfoList) {
				TEmployeeInfo tEmployeeInfoOld = tEmployeeInfoService.getById(tEmployeeInfo.getId());
				//查询该人员所有的项目档案
				List<TEmployeeProject> list = tEmployeeProjectService.list(Wrappers.<TEmployeeProject>query().lambda()
						.eq(TEmployeeProject::getEmpIdcard, tEmployeeInfo.getEmpIdcard())
						.eq(TEmployeeProject::getDeleteFlag, CommonConstants.STATUS_NORMAL)
						.eq(TEmployeeProject::getProjectStatus, CommonConstants.ZERO_INT));
				for (TEmployeeProject tEmployeeProject:list) {
					if (CommonConstants.ZERO_STRING.equals(tEmployeeProject.getEmpNatrue())) {
						tEmployeeInfo.setEmpNatrue(CommonConstants.ZERO_STRING);
						break;
					} else if (CommonConstants.ONE_STRING.equals(tEmployeeProject.getEmpNatrue()) && !CommonConstants.ZERO_STRING.equals(tEmployeeInfo.getEmpNatrue())) {
						tEmployeeInfo.setEmpNatrue(CommonConstants.ONE_STRING);
						break;
					}
					tEmployeeInfo.setEmpNatrue(CommonConstants.TWO_STRING);
				}
				tEmployeeInfoService.updateById(tEmployeeInfo);
				tEmployeeLogService.saveModificationRecord(CommonConstants.dingleDigitIntArray[0]
						, tEmployeeInfo.getId(), "", tEmployeeInfoOld, tEmployeeInfo);
			}
        } catch (Exception e) {
            log.error("档案-批量更新人员档案错误", e);
        }
        log.info("档案-批量更新人员档案结束");
    }

}
